<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Boat;
use App\Models\BoatCategory;
use Illuminate\Http\Request;

class CategoryController extends Controller
{
    public function index()
    {
        $pageTitle              = 'Boat Category Information';
        $categories             = BoatCategory::orderBy('id', 'desc')->paginate(getPaginate(10));

        return view('admin.category.index', compact('pageTitle', 'categories'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'name'              => 'required|max:255|unique:boat_categories,name',
        ]);

        $category               = new BoatCategory();
        $category->name         = $request->name;
        $category->save();

        $notify[]               = ['success', 'Category Created successfully.'];
        return back()->withNotify($notify);
    }

    public function edit(Request $request,$id)
    {
        $request->validate([
            'name'              => 'required|max:255',
        ]);
        $category               = BoatCategory::findOrFail($id);
        $check = BoatCategory::where('name', $request->name)->whereNot('id', $category->id)->get();
        if($check->count() > 0)
        {
            $notify[]           = ['error', 'Category name already exists.'];
            return back()->withNotify($notify);
        }

        $category->name         = $request->name;
        $category->save();
        $notify[]           = ['success', 'Category has been updated.'];
        return back()->withNotify($notify);
    }


    public function status($id)
    {
        $category               = BoatCategory::findOrFail($id);
        if($category->status == 1)
        {
            $category->status   = 0;
            $category->save();

            $notify[]           = ['error', 'Category status successfully changed.'];
            return to_route('admin.category.list')->withNotify($notify);
        }else
        {
            $category->status   = 1;
            $category->save();

            $notify[]           = ['success', 'Category status successfully changed.'];
            return to_route('admin.category.list')->withNotify($notify);
        }

    }
}
