<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Boat;
use App\Models\Image;
use App\Models\Location;
use App\Rules\FileTypeValidate;
use Illuminate\Http\Request;

class LocationController extends Controller
{
    public function index()
    {
        $pageTitle              = 'Location Information';
        $locations              = Location::orderBy('id', 'desc')->paginate(getPaginate(10));
        return view('admin.location.index', compact('pageTitle', 'locations'));
    }
    public function create()
    {
        $pageTitle              = 'Location Create';
        $countries              = json_decode(file_get_contents(resource_path('views/partials/country.json')));
        return view('admin.location.create', compact('pageTitle', 'countries'));
    }

    public function store(Request $request)
    {
        $countryData            = (array)json_decode(file_get_contents(resource_path('views/partials/country.json')));
        $countries              = implode(',',array_column($countryData, 'country'));

        $request->validate([
            'name'              => 'required|string',
            'city'              => 'required|string',
            'state'             => 'nullable|string',
            'zip'               => 'nullable|numeric',
            'latitude'          => 'required|numeric',
            'longitude'         => 'required|numeric',
            'country'           => 'required|in:'.$countries,
            'additonal.*'       => 'required',
            'image'             => ['required', 'image', new FileTypeValidate(['jpg', 'jpeg', 'png'])],
        ]);

        $check = Location::where('name', $request->name)->where('city', $request->city)->where('state', $request->state)->where('country', $request->country)->get();
        if($check->count() > 0)
        {
            $notify[]           = ['error', 'Location already exists.'];
            return redirect()->back()->withInput($request->all())->with('notify', $notify);
        }
  
        $location               = new Location();
        $location->name         = $request->name;
        $location->city         = $request->city;
        $location->state        = $request->state;
        $location->zip          = $request->zip;
        $location->longitude    = $request->longitude;
        $location->latitude     = $request->latitude;
        $location->country      = $request->country;
        $location->address_line = json_encode($request->address);
        $location->save();

        if($request->image){
            $newImage           = new Image();   
            $newImage->location_id = $location->id;
            try {
                $newImage->image = fileUploader($request->image, getFilePath('locationImage'),getFileSize('locationImage'));
            } catch (\Exception $exp) {
                $notify[]        = ['error', 'Couldn\'t upload your image'];
                return back()->withNotify($notify);
            }
            $newImage->save();
        }

        $notify[]                = ['success', 'Location Created successfully.'];
        return to_route('admin.location.list')->withNotify($notify);
      
    }
    public function status($id)
    {
        $location               = Location::findOrFail($id);
        if($location->status == 1)
        {
            $location->status   = 0;
            $location->save();

            $notify[]           = ['error', 'Location status successfully changed.'];
            return to_route('admin.location.list')->withNotify($notify);
        }else
        {
            $location->status   = 1;
            $location->save();

            $notify[]           = ['success', 'Location status successfully changed.'];
            return to_route('admin.location.list')->withNotify($notify);
        }

    }
    public function edit(Request $request,$id)
    {
        $pageTitle              = 'Location Information Edit';
        $location               = Location::findOrFail($id);
        $countries              = json_decode(file_get_contents(resource_path('views/partials/country.json')));
        $images                 = Image::where('location_id', $location->id)->first();
        $locations              = Location::all();

        return view('admin.location.edit', compact('pageTitle','location', 'countries', 'images'));
    }
    public function update(Request $request, $id)
    {
        $countryData            = (array)json_decode(file_get_contents(resource_path('views/partials/country.json')));
        $countries              = implode(',',array_column($countryData, 'country'));
        $request->validate([
            'name'              => 'required|string',
            'city'              => 'required|string',
            'state'             => 'nullable|string',
            'zip'               => 'nullable|numeric',
            'latitude'          => 'required|numeric',
            'longitude'         => 'required|numeric',
            'country'           => 'required|in:'.$countries,
            'address.*'         => 'string',
            'image'             => ['image', new FileTypeValidate(['jpg', 'jpeg', 'png'])],
        ]);

        $location               = Location::findOrFail($id);
        $check = Location::where('name', $request->name)->where('city', $request->city)->where('state', $request->state)->where('country', $request->country)->whereNot('id', $location->id)->get();
        if($check->count() > 0)
        {
            $notify[]           = ['error', 'Location already exists.'];
            return back()->withNotify($notify);
        }
        $location->name         = $request->name;
        $location->city         = $request->city;
        $location->state        = $request->state;
        $location->zip          = $request->zip;
        $location->longitude    = $request->longitude;
        $location->latitude     = $request->latitude;
        $location->country      = $request->country;
        $location->address_line = json_encode($request->address);
        $location->save();

        if($request->image){
            $image              =  Image::where('location_id', $location->id)->first();
            $path               = getFilePath('locationImage');
            fileManager()->removeFile($path.'/'.$image->image);
            $image->delete();

            $newImage           = new Image();   
            $newImage->location_id = $location->id;
            try {
                $newImage->image = fileUploader($request->image, getFilePath('locationImage'),getFileSize('locationImage'));
            } catch (\Exception $exp) {
                $notify[] = ['error', 'Couldn\'t upload your image'];
                return back()->withNotify($notify);
            }
            $newImage->save();
        }

        $notify[]                   = ['success', 'Location Updated successfully.'];
        return to_route('admin.location.list')->withNotify($notify);
    }

}
