<?php

namespace App\Http\Controllers;

use App\Models\AdminNotification;
use App\Models\Boat;
use App\Models\BoatCategory;
use App\Models\Booking;
use App\Models\BookingRequest;
use App\Models\Frontend;
use App\Models\Image;
use App\Models\Language;
use App\Models\Location;
use App\Models\Page;
use App\Models\SupportMessage;
use App\Models\SupportTicket;
use Carbon\Carbon;
use Carbon\CarbonPeriod;
use DateTimeZone;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Cookie;
use Nette\Utils\DateTime;

class SiteController extends Controller {
    public function index() {
        $reference              = @$_GET['reference'];
        if ($reference) {
            session()->put('reference', $reference);
        }
        
        $pageTitle              = 'Home';
        $sections               = Page::where('tempname', $this->activeTemplate)->where('slug', '/')->first();

        return view($this->activeTemplate . 'home', compact('pageTitle', 'sections'));
    }

    public function pages($slug) {
        $page                   = Page::where('tempname', $this->activeTemplate)->where('slug', $slug)->firstOrFail();
        $pageTitle              = $page->name;
        $sections               = $page->secs;

        return view($this->activeTemplate . 'pages', compact('pageTitle', 'sections'));
    }

    public function search(Request $request)
    {
        $categories             = BoatCategory::where('status', 1)->get();
        $locations              = Location::where('status', 1)->get();
        $title                  = 'Name';
        $pageTitle              =   'Boat Search';
        $search                 = $request->boat;
        
        $conditions = [];

        if ($request->category) {
            $conditions[] = ['category_id', $request->category];
        }

        if($request->boat){
            $conditions[] = ['name', 'like', "%$search%"];
        }

        if($request->location){
            $conditions[] = ['location_id', $request->location];
        }

        if($request->passengers){
            $conditions[] = ['passengers', '>=', $request->passengers];
        }

        $boats = Boat::where($conditions)->where('status', 1)->with('image', 'location', 'category')->orderBy('id', 'DESC')->paginate(getPaginate(10));

        return view($this->activeTemplate . 'searchboats', compact('pageTitle','boats', 'title', 'categories', 'locations'));
    }

    public function allYachts()
    {
        $pageTitle              = "Browse";
        $categories             = BoatCategory::where('status', 1)->get();
        $randomCategories       = BoatCategory::where('status', 1)->inRandomOrder()->limit(5)->get();
        $locations              = Location::where('status', 1)->get();
        $boats                  = Boat::where('status', 1)->with('image', 'location', 'category')->orderBy('id', 'desc')->paginate(getPaginate(10));
        return view($this->activeTemplate.'allyachts',compact('boats','locations','categories','pageTitle', 'randomCategories'));  
    }

    public function contact() {
        $pageTitle              = "Contact Us";
        return view($this->activeTemplate . 'contact', compact('pageTitle'));
    }

    public function contactSubmit(Request $request) {
        $this->validate($request, [
            'name'              => 'required',
            'email'             => 'required',
            'subject'           => 'required|string|max:255',
            'message'           => 'required',
        ]);

        if (!verifyCaptcha()) {
            $notify[]           = ['error', 'Invalid captcha provided'];
            return back()->withNotify($notify);
        }

        $request->session()->regenerateToken();

        $random                 = getNumber();

        $ticket                 = new SupportTicket();
        $ticket->user_id        = auth()->id() ?? 0;
        $ticket->name           = $request->name;
        $ticket->email          = $request->email;
        $ticket->priority       = 2;
        $ticket->ticket         = $random;
        $ticket->subject        = $request->subject;
        $ticket->last_reply     = Carbon::now();
        $ticket->status         = 0;
        $ticket->save();

        $adminNotification      = new AdminNotification();
        $adminNotification->user_id         = auth()->user() ? auth()->user()->id : 0;
        $adminNotification->title           = 'A new support ticket has opened ';
        $adminNotification->click_url       = urlPath('admin.ticket.view', $ticket->id);
        $adminNotification->save();

        $message                = new SupportMessage();
        $message->support_ticket_id         = $ticket->id;
        $message->message       = $request->message;
        $message->save();

        $notify[]               = ['success', 'Ticket created successfully!'];

        return to_route('ticket.view', [$ticket->ticket])->withNotify($notify);
    }

    public function bookingRequest(Request $request)
    {
        $start_date             = Carbon::parse(date('Y-m-d', strtotime($request->from_date))); 
        $end_date               = Carbon::parse(date('Y-m-d', strtotime($request->from_date)));
   
        $request->validate([
            'user_name'         => 'required|string',
            'passenger'         => 'required|numeric',
            'from_date'         => 'required',
            'to_date'           => 'required',
            'category'          => 'required|exists:boat_categories,id',
            'email'             => 'required|string|email',
            'phone'             => 'required|numeric',
            'message'           => 'required|string',
        ]);

        $data            = new BookingRequest();
        $data->user_name = $request->user_name;
        $data->passenger = $request->passenger;
        $data->from_date = $start_date;
        $data->to_date   = $end_date;
        $data->boat_category_id = $request->category;
        $data->email     = $request->email;
        $data->phone     = $request->phone;
        $data->message   = $request->message;
        $data->save();

        $notify[]               = ['success', 'Booking request successfully done!.'];
        return redirect()->back()->withNotify($notify);

    }


    public function boatDetailsSingle($slug, $id)
    {
        $locations              = Location::where('status', 1)->get();
        $boat                   = Boat::findOrFail($id);
        $images                 = Image::where('boat_id', $boat->id)->get();
        $categories             = BoatCategory::where('status', 1)->get();
        $randomCategories       = BoatCategory::where('status', 1)->inRandomOrder()->limit(5)->get();
        $bookings               = Booking::where('status', 1)->where('boat_id', $boat->id)->get();
        $pageTitle              = $boat->name.' Details';
        $dates = [];
        foreach($bookings as $data)
        {
            $period             = CarbonPeriod::create($data->from_date, $data->to_date);
            foreach ($period as $date) {
                array_push($dates, $date->format('d/m/Y'));
            }
        }
       
        return view($this->activeTemplate . 'boatDetails', compact('boat', 'pageTitle', 'categories', 'images', 'dates', 'locations', 'randomCategories'));

    }

    public function policyPages($slug, $id) 
    {
        $policy             = Frontend::where('id', $id)->where('data_keys', 'policy_pages.element')->firstOrFail();
        $pageTitle          = $policy->data_values->title;

        return view($this->activeTemplate . 'policy', compact('policy', 'pageTitle'));
    }

    public function changeLanguage($lang = null) 
    {
        $language           = Language::where('code', $lang)->first();
        if (!$language)
            $lang           = 'en';
        session()->put('lang', $lang);
        return back();
    }

    public function blog() 
    {
        $pageTitle          = 'Blog Page';
        $pageName           = 'Blog';
        $sections           = Page::where('tempname', $this->activeTemplate)->where('slug', 'blog')->firstOrFail();
        $elements            = Frontend::where('data_keys', 'blog.element')->orderBy('id', 'desc')->paginate(getPaginate(10));

        return view($this->activeTemplate . 'blog', compact('pageTitle', 'pageName', 'sections', 'elements'));
    }

    public function about() 
    {
        $pageTitle          = 'About Us';
        $pageName           = 'About';
        $sections           = Page::where('tempname', $this->activeTemplate)->where('slug', 'about-us')->firstOrFail();
        $element            = Frontend::where('data_keys', 'blog.element')->orderBy('id', 'desc')->paginate(getPaginate(12));

        return view($this->activeTemplate . 'about_us', compact('pageTitle', 'pageName', 'sections', 'element'));
    }


    public function blogdetails($slug, $id)
    {
        $pageTitle          = 'Blog Details';
        $categories         = BoatCategory::where('status', 1)->get();
        $sections           = Page::where('tempname',$this->activeTemplate)->where('slug','blog')->firstOrFail();  
        $element            = Frontend::where('id',$id)->where('data_keys','blog.element')->firstOrFail();

        return view($this->activeTemplate.'blog_details',compact('pageTitle', 'sections', 'element', 'categories'));
    }

    
    public function locationBoat($slug, $id)
    {
        $categories             = BoatCategory::where('status', 1)->get();
        $locations              = Location::where('status', 1)->get();
        $location           = Location::findOrFail($id);
        $boats              = Boat::where('location_name', $location->name)->with('image')->orderBy('id', 'desc')->paginate(getPaginate(10));
        $pageTitle          = 'Available Boats';
        $title              = 'Location';
        // $heading            = $location->name;
        // $description        = 'You are searching '.$location->name.'\'s available boats.';
        // return view($this->activeTemplate . 'searchboats', compact('pageTitle','boats', 'location', 'title', 'heading', 'description', 'categories', 'locations'));
        return view($this->activeTemplate . 'searchboats', compact('pageTitle','boats', 'location', 'title', 'categories', 'locations'));

    }


    public function categoryBoat($slug, $id)
    {
        $categories             = BoatCategory::where('status', 1)->get();
        $locations              = Location::where('status', 1)->get();

        $category           = BoatCategory::findOrFail($id);
        $boats              = Boat::where('category_id', $category->id)->orderBy('id', 'desc')->paginate(getPaginate(12));
        $pageTitle          = 'Available Boats';
        $title              = 'Category';
        // $heading            = $category->name;
        // $description        = 'You are searching '.$category->name.'\'s available boats.';  
        // return view($this->activeTemplate . 'searchboats', compact('pageTitle','boats', 'category', 'title', 'heading', 'description', 'categories', 'locations'));  
        return view($this->activeTemplate . 'searchboats', compact('pageTitle','boats', 'category', 'title', 'categories', 'locations'));  
    }


    public function cookieAccept() {
        $general            = gs();
        Cookie::queue('gdpr_cookie', $general->site_name, 43200);
        return back();
    }

    public function cookiePolicy() {
        $pageTitle          = 'Cookie Policy';
        $cookie             = Frontend::where('data_keys', 'cookie.data')->first();

        return view($this->activeTemplate . 'cookie', compact('pageTitle', 'cookie'));
    }

    public function placeholderImage($size = null) {
        $imgWidth           = explode('x', $size)[0];
        $imgHeight          = explode('x', $size)[1];
        $text               = $imgWidth . '×' . $imgHeight;
        $fontFile           = realpath('assets/font') . DIRECTORY_SEPARATOR . 'RobotoMono-Regular.ttf';
        $fontSize           = round(($imgWidth - 50) / 8);
        if ($fontSize <= 9) {
            $fontSize       = 9;
        }
        if ($imgHeight < 100 && $fontSize > 30) {
            $fontSize       = 30;
        }

        $image              = imagecreatetruecolor($imgWidth, $imgHeight);
        $colorFill          = imagecolorallocate($image, 255, 255, 255);
        $bgFill             = imagecolorallocate($image, 28, 35, 47);
        imagefill($image, 0, 0, $bgFill);
        $textBox            = imagettfbbox($fontSize, 0, $fontFile, $text);
        $textWidth          = abs($textBox[4] - $textBox[0]);
        $textHeight         = abs($textBox[5] - $textBox[1]);
        $textX              = ($imgWidth - $textWidth) / 2;
        $textY              = ($imgHeight + $textHeight) / 2;
        header('Content-Type: image/jpeg');
        imagettftext($image, $fontSize, 0, $textX, $textY, $colorFill, $fontFile, $text);
        imagejpeg($image);
        imagedestroy($image);
    }
}