<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use App\Models\Boat;
use App\Models\Booking;
use App\Models\GatewayCurrency;
use Carbon\Carbon;
use Carbon\CarbonPeriod;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Date;
use Nette\Utils\DateTime;

class BoatBookingController extends Controller
{
    public function booking($id, Request $request)
    {
        $start_date             = $request->start_booking; 
        $end_date               = $request->end_booking;

        $newStartDate           = Carbon::createFromFormat('d/m/Y', $start_date)->format('Y-m-d');
        $newEndDate             = Carbon::createFromFormat('d/m/Y', $end_date)->format('Y-m-d');
        $newStartDateCount      = Carbon::parse($newStartDate);
        $newEndDateCount        = Carbon::parse($newEndDate);

        $days                   = $newStartDateCount->diffInDays($newEndDateCount) + 1;

        $boat                   = Boat::findOrFail($id);

        $bookings               = Booking::where('status', 1)->where('boat_id', $boat->id)->get();

        $allBooking             = [];
        foreach($bookings as $data)
        {
            $period             = CarbonPeriod::create($data->from_date, $data->to_date);
            foreach ($period as $date) {
                array_push($allBooking, $date->format('d/m/Y'));
            }
        }

        $newBooking             = [];
        $period                 = CarbonPeriod::create( $newStartDate, $newEndDate);
        foreach ($period as $date) {
            array_push($newBooking, $date->format('d/m/Y'));
        }

        $array_intersect        = array_intersect($allBooking, $newBooking);
        $count                  = count($array_intersect);

        if($count != 0)
        {
            $notify[]           = ['error', 'Days that are already booked can\'t be chosen.'];
            return back()->withNotify($notify);
        }

        $booking                = new Booking();
        $booking->user_id       = auth()->user()->id;
        $booking->boat_id       = $boat->id;
        $booking->boat_name         = $boat->name;
        $booking->location_id = $boat->location_id;
        $booking->from_date     = $newStartDate;
        $booking->to_date       = $newEndDate;

        $booking->count_date    = $days;
        $booking->price         = $days * $boat->price;
        $booking->trx           = getTrx();
        $booking->save();

        $gatewayCurrency        = GatewayCurrency::whereHas('method', function ($gate) {
            $gate->where('status', 1);
        })->with('method')->orderby('method_code')->get();
        $pageTitle              = 'Payment Page';

        return view($this->activeTemplate . 'user.payment.deposit', compact('gatewayCurrency', 'pageTitle', 'booking'));
    }
}
