@extends('admin.layouts.app')
@section('panel')


<div class="d-flex flex-wrap justify-content-end mb-3">
    <div class="d-inline">
        <div class="input-group justify-content-end">
            <input type="text" name="search_table" class="form-control bg--white"
                placeholder="@lang('Search Category')...">
            <button class="btn btn--primary input-group-text"><i class="fa fa-search"></i></button>
        </div>
    </div>
</div>

<div class="row">
    <div class="col-lg-12">
        <div class="card">
            <div class="card-body p-0">
                <div class="table-responsive--sm table-responsive">
                    <table class="table table--light style--two custom-data-table">
                        <thead>
                            <tr>
                                <th>@lang('SL')</th>
                                <th>@lang('Name')</th>
                                <th>@lang('status')</th>
                                <th>@lang('Action')</th>
                            </tr>
                        </thead>
                        <tbody class="list">
                            @forelse($categories as $key=>$category)
                            <tr>
                                <td>{{$key+1}}</td>
                                <td>{{$category->name}}</td>
                                <td>
                                    @if($category->status == 1)
                                    <span
                                        class="text--small badge font-weight-normal badge--success">@lang('Active')</span>
                                    @endif

                                    @if($category->status == 0)
                                    <span
                                        class="text--small badge font-weight-normal badge--danger">@lang('Inactive')</span>
                                    @endif
                                </td>
                                <td>
                                    <a href="javascript:void(0)" class="btn btn-sm btn-outline--primary ms-1 editBtn" title="Edit" data-url="{{ route('admin.category.edit', $category->id)}}" data-data="{{ json_encode($category->only('name')) }}">
                                        <i class="la la-pen"></i>
                                    </a>

                                    <button class="btn btn-sm btn--danger confirmationBtn" title="@lang('Change Status')" data-question="@lang('Are you sure to change category status from this system?')" data-action="{{ route('admin.category.status', $category->id) }}">
                                        <i class="las la-sync"></i>
                                    </button>
                                    <x-confirmation-modal></x-confirmation-modal>
                                </td>
                            </tr>
                            @empty
                            <tr>
                                <td class="text-muted text-center" colspan="100%">{{ $emptyMessage }}</td>
                            </tr>
                            @endforelse
                        </tbody>
                    </table>
                </div>
            </div>

            @if ($categories->hasPages())
                <div class="card-footer py-4">
                    @php echo paginateLinks($categories) @endphp
                </div>
            @endif

        </div>
    </div>
</div>


@push('breadcrumb-plugins')
    <a href="javascript:void(0)" class="btn btn-sm btn-outline--primary addCity">@lang('Add New')</a>
@endpush



{{-- Add METHOD MODAL --}}
<div id="cityModel" class="modal fade" tabindex="-1" role="dialog">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title"> @lang('Add Category')</h5>
                <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                    <i class="las la-times"></i>
                </button>
            </div>
            <form action="{{ route('admin.category.store') }}" class="edit-route" method="POST" enctype="multipart/form-data">
                @csrf

                <div class="modal-body">
                    <div class="row">
                        <div class="col-md-12 col-lg-12">
                            <div class="form-group">
                                <label>@lang('Category Name')</label>
                                <div class="input-group">
                                    <input type="text" class="form-control" autocomplete="off" name="name" value="{{old('name')}}" required>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="submit" class="btn btn--primary btn-global">@lang('Save')</button>
                </div>
            </form>
        </div>
    </div>
</div>


{{-- EDIT MODAL --}}
<div class="modal fade" id="editModal" tabindex="-1" role="dialog" aria-labelledby="editModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title" id="editModalLabel">@lang('Edit Category')</h4>
                <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close"><i
                        class="las la-times"></i></button>
            </div>
            <form method="get">
                @csrf
                <div class="modal-body">
                    <div class="form-group">
                        <label>@lang('Category Name')</label>
                        <div class="col-sm-12">
                            <input type="text" class="form-control" value="{{ old('name') }}" name="name" required>
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="submit" class="btn btn--primary h-45" id="btn-save"
                        value="add">@lang('Submit')</button>
                </div>
            </form>
        </div>
    </div>
</div>


@endsection

@push('script')
<script>
    (function ($) {
        "use strict";

        $('.addCity').on('click', function() {
            $('#cityModel').modal('show');
        });


        $('.editBtn').on('click', function () {
            var modal = $('#editModal');
            var url = $(this).data('url');
            var data = $(this).data('data');

            modal.find('form').attr('action', url);
            modal.find('input[name=name]').val(data.name);
            modal.modal('show');
        });
    })(jQuery);

</script>
@endpush
