@extends('admin.layouts.app')
@section('panel')

<div class="row">
    <div class="col-lg-12">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title">@lang('New Location Create')</h5>
            </div>
            <div class="card-body p-3">

                <form action="{{ route('admin.location.store') }}" class="edit-route" method="POST" enctype="multipart/form-data">
                    @csrf
                    <div class="row">
                        <div class="col-md-6 col-lg-6">
                            <div class="form-group">
                                <label>@lang('Location Name')</label>
                                <div class="input-group">
                                    <input type="text" class="form-control" autocomplete="off" name="name" value="{{old('name')}}" required>
                                </div>
                            </div>
                        </div>

                        <div class="col-md-6 col-lg-6">
                            <div class="form-group">
                                <label>@lang('City')</label>
                                <div class="input-group">
                                    <input type="text" class="form-control form--control" autocomplete="off" name="city" value="{{old('city')}}" required>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-6 col-lg-6">
                            <div class="form-group">
                                <label>@lang('Country')</label>
                                <div class="col-12">
                                    <select name="country" class="form-control form--control" required>
                                        @foreach ($countries as $key => $country)
                                        <option value="{{ $country->country }}" {{old('country') == $country->country ? 'selected' : ''}}> {{ __($country->country) }}</option>
                                        @endforeach
                                    </select>
                                </div>
                            </div>
                        </div>

                        <div class="col-md-6 col-lg-6">
                            <div class="form-group">
                                <label>@lang('State (optional)')</label>
                                <div class="input-group">
                                    <input type="text" class="form-control form--control" autocomplete="off" name="state" value="{{old('state')}}">
                                </div>
                            </div>
                        </div>
                    </div>


                    <div class="row">
                        <div class="col-md-6 col-lg-6">
                            <div class="form-group">
                                <label>@lang('Zip Code (optional)')</label>
                                <div class="input-group">
                                    <input type="number" class="form-control" autocomplete="off" name="zip" value="{{old('zip')}}">
                                </div>
                            </div>
                        </div>
                        <div class="col-md-6 col-lg-6">
                            <div class="form-group">
                                <label>@lang('Location Image')</label>
                                <div class="input-group">
                                    <input type="file" class="form-control" autocomplete="off" name="image" required accept=".jpg, .png, .jpeg">
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="row">
                        <div class="col-md-6 col-lg-6">
                            <div class="form-group">
                                <label>@lang('Longitude')</label>
                                <div class="input-group">
                                    <input type="number" class="form-control" autocomplete="off" name="longitude" value="{{old('longitude')}}" required step="any">
                                </div>
                            </div>
                        </div>
                        <div class="col-md-6 col-lg-6">
                            <div class="form-group">
                                <label>@lang('Latitude')</label>
                                <div class="input-group">
                                    <input type="number" class="form-control" autocomplete="off" name="latitude" value="{{old('latitude')}}" required step="any">
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="row">
                        <div class="row form-group">
                            <div class="col-11">
                                <label class="text-left mb-15">@lang('Address Line Information')<span class="text-danger">*</span></label>
                            </div>
                            <div class="col-1">
                                <button type="button" class="btn add-new add_addressline_information btn--primary">
                                    <i class="fa fa-plus"></i>
                                </button>
                            </div>
                        </div>

                        <div class="row addresslineField">
                            <div class="col-md-12 data-address-line">
                                <div class="form-group">
                                    <div class="row">
                                        <div class="col-11">
                                            <input name="address[]" class="form-control" type="text" required placeholder="@lang('Address Line Information')" value="">
                                        </div>
                                        <div class="col-1 text-right">
                                            <span class="">
                                                <button class="btn btn-outline-danger remove_additional_information"
                                                    type="button">
                                                    <i class="la la-times"></i>
                                                </button>
                                            </span>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="text-end mt-15">
                        <button type="submit" class="btn btn--primary btn-lg">@lang('Submit')</button>
                    </div>
                </form>

            </div>
        </div>
    </div>
</div>


@push('breadcrumb-plugins')
    <a href="{{ route('admin.location.list') }}" class="btn btn-sm btn--primary">@lang('Back')</a>
@endpush

@endsection

@push('script')
<script>
    "use strict";

    $('.add_addressline_information').on('click', function () {
        var html = `
            <div class="col-md-12 data-address-line">
                <div class="form-group">
                    <div class="row align-items-center">
                        <div class="col-11">
                            <input name="address[]" class="form-control" type="text" required placeholder="@lang('Address Line Information')" value="">
                        </div>
                        <div class="col-1">
                            <span class="input-group-btn">
                                <button class="btn btn-outline-danger remove_additional_information" type="button">
                                    <i class="la la-times"></i>
                                </button>
                            </span>
                        </div>
                    </div>
                </div>
            </div>`;
        $('.addresslineField').append(html);
    });

    $(document).on('click', '.remove_additional_information', function () {
        $(this).closest('.data-address-line').remove();
    });

</script>
@endpush
